Maintainers
-----------

+ Daniel Williams <daniel.williams@ligo.org>
+ John Veitch <john.veitch@ligo.org>

Contributing Authors
--------------------
+ Rhiannon Udall <rhiannon.udall@ligo.org>
+ Avi Vajpeji
+ Charlie Hoy
  
Review Team
-----------

The review team for Asimov have the unenviable duty of ensuring that everything both works and produces scientifically reliable configurations and results.

+ Patricia Schmidt <patricia.schmidt@ligo.org>
+ Maria Luisa Chiofalo

Acknowledgments
---------------

We'd like to thank the following people for their suggestions and help in producing this software.

+ Duncan Macleod
